/**
 * Copyright 2006 by jFramework.org.
 */
package org.jframework.core.util;

import junit.framework.Assert;

import java.util.EventListener;
import java.util.EventObject;
import java.util.LinkedList;

/**
 * Event sink serves as the base for all mock event listeners.  It is thread safe.
 *
 * @author mgridnev
 * @version 2.0, Dec 7, 2006
 */
public class EventSink<Event extends EventObject> implements EventListener
{
    /**
     * Events
     */
    private LinkedList<Event> events = new LinkedList<Event>();

    /**
     * Returns a list of all events
     *
     * @return an copy of the event list
     */
    public synchronized LinkedList<Event> getEvents()
    {
        return new LinkedList<Event>(events);
    }

    /**
     * Clears event list
     */
    public synchronized void clear()
    {
        events.clear();
    }

    /**
     * Adds an event to the list
     */
    protected synchronized void addEvent(Event event)
    {
        events.add(event);
    }

    /**
     * Asserts event count
     *
     * @param cEvents event count
     */
    public void assertEventCount(int cEvents)
    {
        Assert.assertEquals("Event count", cEvents, events.size());
    }
}
